# Generated by Django 4.1.4 on 2022-12-23 01:44

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('password_policies', '0004_alter_passwordrecord_options'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='passwordrecord',
            options={'get_latest_by': 'date', 'ordering': ['-date']},
        ),
    ]
